@@ -1,4 +1,4 @@
-/* $Id: xdial.h,v 1.1 1998/07/26 05:47:59 glgay Exp $ */
+/* $Id: xdial.h,v 1.4 1999/11/06 05:50:56 glgay Exp $ */
 /*
  Copyright (C) 1996 Peter Williams
  
@@ -22,6 +22,7 @@
 #include <vector>
 #include <Xarm/AppContext.h>
 #include <Xarm/Dial.h>
+#include <Xarm/Xarm.h>
 
 char *basename(char *);
 
@@ -32,7 +33,11 @@ class DialDemo: public AppContext
    void   onInc(Widget,XtPointer,XtPointer);
    void   exit(Widget,XtPointer,XtPointer);
 
+#if defined(XARM_HAS_NAMESPACES)
+   std::vector<Dial *>  dials; 
+#else
    vector<Dial *>  dials; 
+#endif
    Form           *main_form;
    Label          *label;
    Form           *dial_form;
