@@ -1,7 +1,8 @@
-/* $Id: AppContext.h,v 1.2 1999/01/14 00:43:58 glgay Exp $ */
+/* $Id: AppContext.h,v 1.4 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1998, 1999 Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,12 +20,14 @@
 */
 
 
-#if !defined(_XARM_APPCONTEXT_H_)
-#define _XARM_APPCONTEXT_H_
+#if !defined(xarm_appcontext_h)
+#define xarm_appcontext_h
 
 /* ======================================================================= */
 /* Include(s): */
 #include <Xarm/ApplicationS.h>
+#include <Xarm/ImageCache.h>
+
 
 /*
 *  Author's note:  Although it is not stated (to my knowledge), the
@@ -41,59 +44,80 @@ class AppContextClass : public ApplicationShellClass {
     * This is called right after AppInit routine.
     */
  protected:
-   void registerConverters();
+   void registerConverters() { XarmRegisterConverters(); }
 
    void appContext(const XtAppContext ac) { app_context = ac; }
    AppContextClass() {}
  public:
-   void addActions(const XtActionList actions, const Cardinal no);
+   void addActions(const XtActionList actions, const Cardinal no)
+     { XtAppAddActions(appContext(), actions, no); }
    void addConverter(_XtString from_type, 
                      _XtString to_type, 
                      XtConverter converter,
                      XtConvertArgList convert_args, 
-                     Cardinal no_args);
+                     Cardinal no_args)
+     {  XtAppAddConverter(appContext(),
+			  from_type,
+			  to_type,
+			  converter,
+			  convert_args,
+			  no_args); }
    XtInputId addInput(int source,XtPointer condition, XtInputCallbackProc proc,
-                      XtPointer client_data);
+                      XtPointer client_data)
+     { return XtAppAddInput(appContext(), source, condition, proc, client_data); }
    XtIntervalId addTimeOut(unsigned long interval, XtTimerCallbackProc proc, 
-                           XtPointer client_data);
-   XtWorkProcId addWorkProc(XtWorkProc proc, XtPointer client_data);
-   Boolean dispatchEvent(XEvent *event);
-   void error(const _XtString msg);
+                           XtPointer client_data)
+     { return XtAppAddTimeOut(appContext(), interval, proc, client_data); }
+   XtWorkProcId addWorkProc(XtWorkProc proc, XtPointer client_data)
+     { return XtAppAddWorkProc(appContext(), proc, client_data); }
+   Boolean dispatchEvent(XEvent *event) { return XtDispatchEvent(event); }
+   void error(const _XtString msg) { XtAppError(appContext(), msg); }
    void errorMsg(_XtString name, 
                  _XtString type, 
                  _XtString _class, 
                  _XtString _default,
                  _XtString *params, 
-                 Cardinal *no);
-   XrmDatabase *getErrorDatabase();
+                 Cardinal *no)
+     { XtAppErrorMsg(appContext(), name, type, _class, _default, params, no); }
+   XrmDatabase *getErrorDatabase() { return XtAppGetErrorDatabase(appContext()); }
    void getErrorDatabaseText(char *name, char *type, char *_class,
                              char *_default, char *buffer_return, int nbytes, 
-                             XrmDatabase database);
-   unsigned long getSelectionTimeout() const;
+                             XrmDatabase database)
+     {  XtAppGetErrorDatabaseText(appContext(),name,type,_class,_default,
+				  buffer_return, nbytes, database); }
+   unsigned long getSelectionTimeout() const
+     { return XtAppGetSelectionTimeout(appContext()); }
    void mainLoop();
-   void nextEvent(XEvent * event_return);
-   void processEvent(XtInputMask mask); 
-   Boolean peekEvent(XEvent * event_return);
-   XtInputMask pending();
+   void nextEvent(XEvent * event_return) { XtAppNextEvent(appContext(),event_return); }
+   void processEvent(XtInputMask mask) { XtAppProcessEvent(appContext(),mask); }
+   Boolean peekEvent(XEvent * event_return)
+     { return XtAppPeekEvent(appContext(), event_return); }
+   XtInputMask pending() { return XtAppPending(appContext()); }
    
-   void removeInput(XtInputId id);
-   void removeTimeOut(XtIntervalId timer);
-   void removeWorkProc(XtWorkProcId id);
-   void setErrorHandler(XtErrorHandler handler);
-   void setErrorMsgHandler(XtErrorMsgHandler handler);
-   void setSelectionTimeout(unsigned long timeout);
-   void setWarningHandler(XtErrorHandler handler);
-   void setWarningMsgHandler(XtErrorMsgHandler handler);
-   void warning(_XtString msg);
+   void removeInput(XtInputId id) { XtRemoveInput(id); }
+   void removeTimeOut(XtIntervalId timer) { XtRemoveTimeOut(timer); }
+   void removeWorkProc(XtWorkProcId id) { XtRemoveWorkProc(id); }
+   void setErrorHandler(XtErrorHandler handler)
+     { XtAppSetErrorHandler(appContext(), handler); }
+   void setErrorMsgHandler(XtErrorMsgHandler handler)
+     { XtAppSetErrorMsgHandler(appContext(), handler); }
+   void setSelectionTimeout(unsigned long timeout)
+     { XtAppSetSelectionTimeout(appContext(), timeout); }
+   void setWarningHandler(XtErrorHandler handler)
+     { XtAppSetWarningHandler(appContext(), handler); }
+   void setWarningMsgHandler(XtErrorMsgHandler handler)
+     { XtAppSetWarningMsgHandler(appContext(), handler); }
+   void warning(_XtString msg) { XtAppWarning(appContext(), msg); }
    void warningMsg(_XtString name, 
                    _XtString type, 
                    _XtString _class, 
                    _XtString _default,
-                   _XtString *params, Cardinal *no);
+                   _XtString *params, Cardinal *no)
+     { XtAppWarningMsg(appContext(), name, type, _class, _default, params, no); }
    
    /* extras */
    XtAppContext appContext() const { return app_context; }
-   operator XtAppContext() const; // auto cast self to XtApp 
+   operator XtAppContext() const   { return app_context; }
 
    // termPending() tells whether we are about to exit.
    // This might be useful to someone.
