@@ -1,4 +1,4 @@
-/* $Id: ApplicationS.h,v 1.2 1999/01/14 03:08:53 glgay Exp $ */
+/* $Id: ApplicationS.h,v 1.4 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -19,8 +19,8 @@
 */
 
 
-#if !defined(_XARM_APPLICATIONS_H_)
-#define _XARM_APPLICATIONS_H_
+#if !defined(xarm_applications_h)
+#define xarm_applications_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -33,10 +33,10 @@ class ApplicationShellClass : public TopLevelShellClass {
    virtual WidgetClass classPointer() { return applicationShellWidgetClass; }
    virtual _XtString className() { return (_XtString) "ApplicationShell"; }
  public:
-   int argc() const;
-   void argc(int);
-   _XtString *argv() const;
-   void argv(const _XtString *);
+   int argc() const                { XARM_GET_VALUE(int, XmNargc); }
+   void argc(int val)              { XARM_SET_VALUE(XmNargc); }
+   _XtString *argv() const         { XARM_GET_VALUE(_XtString *, XmNargv); }
+   void argv(const _XtString *val) { XARM_SET_VALUE(XmNargv); }
 };
 
 #endif
