@@ -1,7 +1,8 @@
-/* $Id: ArrowBG.h,v 1.4 1999/01/14 03:35:18 glgay Exp $ */
+/* $Id: ArrowBG.h,v 1.6 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_ARROWBG_H_)
-#define _XARM_ARROWBG_H_
+#if !defined(xarm_arrowbg_h)
+#define xarm_arrowbg_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -34,25 +35,18 @@ class ArrowButtonGadgetClass : public GadgetClass {
    virtual _XtString className() { return (_XtString) "XmArrowButtonGadget"; }
  public:
    /* callbacks */
-   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
-   void armCallback(XtCallbackProc funcp, XtPointer data = NULL);
-   void disarmCallback(XtCallbackProc funcp, XtPointer data = NULL);
+   void activateCallback(XtCallbackProc fp, XtPointer data = NULL)  { XARM_SET_CALLBACK(XmNactivateCallback); }
+   void armCallback(XtCallbackProc fp, XtPointer data = NULL)       { XARM_SET_CALLBACK(XmNarmCallback); }
+   void disarmCallback(XtCallbackProc fp, XtPointer data = NULL)    { XARM_SET_CALLBACK(XmNdisarmCallback); }
 
    /* resources */
-   void arrowDirection(unsigned char);
-   unsigned char arrowDirection() const;
-   void multiClick(unsigned char);
-   unsigned char multiClick() const;
+   void arrowDirection(unsigned char val) { XARM_SET_VALUE(XmNarrowDirection); }
+   unsigned char arrowDirection() const   { XARM_GET_VALUE(unsigned char, XmNarrowDirection); }
+   void multiClick(unsigned char val)     { XARM_SET_VALUE(XmNmultiClick); }
+   unsigned char multiClick() const       { XARM_GET_VALUE(unsigned char, XmNmultiClick); }
 };
 
-class ArrowButtonGadget : public ArrowButtonGadgetClass {
- public:
-   ArrowButtonGadget(Widget w_parent,
-                     ArgList arglist = NULL, 
-                     Cardinal argcnt = 0,
-                     _XtString name = NULL);
-   ArrowButtonGadget(_XtString name, Widget w_parent);
-   ArrowButtonGadget(Widget w_parent, XarmArg &args, _XtString name);
-};
+typedef XarmRawWidget<ArrowButtonGadgetClass, true> ArrowButtonGadget;
+
 
 #endif
