@@ -1,7 +1,7 @@
-/* $Id: Callback.h,v 1.4 1998/04/22 13:14:37 glgay Exp $ */
+/* $Id: Callback.h,v 1.8 1999/12/29 09:30:56 glgay Exp $ */
 /*
- Copyright (C) 1996 Gerald L. Gay
- Copyright (C) 1996 Peter Williams
+ Copyright (C) 1996, 1999 Gerald L. Gay
+ Copyright (C) 1996       Peter Williams
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License
@@ -18,12 +18,21 @@
  Cambridge, MA 02139, USA.
 */
 
-#if !defined(_XARM_CALLBACK_H_)
-#define _XARM_CALLBACK_H_
+#if !defined(xarm_callback_h)
+#define xarm_callback_h
 
 /* ======================================================================= */
 /* Include(s): */
 #include <Xarm/CallbackP.h>
+#include <Xarm/Base.h>
+
+/* ======================================================================= */
+/* ==    There are now two of each function. One taking a Widget,       == */
+/* ==    the other taking a WObjectClass *. Well, for those that        == */
+/* ==    take a Widget argument anyway. :-)                             == */
+/* ======================================================================= */
+
+/* ==========================  addCallback  ============================== */
 
 template<class T>
 void addCallback(T *obj, 
@@ -31,19 +40,41 @@ void addCallback(T *obj,
                  Widget w, 
                  _XtString type, 
                  XtPointer closure=NULL)
-   {
-      CallbackInfo<T> *ci = new CallbackInfo<T>;
+{
+    CallbackInfo<T> *ci = new CallbackInfo<T>;
 
-      if (ci == NULL) return;
+    if (ci == NULL) return;
 
-      ci->_target   = obj;
-      ci->_widget   = w;
-      ci->_type     = type;
-      ci->_callback = func;
-      ci->_closure  = closure;
+    ci->_target   = obj;
+    ci->_widget   = w;
+    ci->_type     = type;
+    ci->_callback = func;
+    ci->_closure  = closure;
 
-      registerCallback(ci);
-   }
+    registerCallback(ci);
+}
+
+template<class T>
+void addCallback(T *obj, 
+                 void (T::*func) (Widget, XtPointer, XtPointer),
+                 const WObjectClass *wo,
+                 _XtString type, 
+                 XtPointer closure=NULL)
+{
+    CallbackInfo<T> *ci = new CallbackInfo<T>;
+
+    if (ci == NULL) return;
+
+    ci->_target   = obj;
+    ci->_widget   = wo->widget();
+    ci->_type     = type;
+    ci->_callback = func;
+    ci->_closure  = closure;
+
+    registerCallback(ci);
+}
+
+/* ======================  addProtocolCallback =========================== */
 
 template <class T>
 void addProtocolCallback(T *obj,
@@ -68,6 +99,31 @@ void addProtocolCallback(T *obj,
 
 }
 
+template <class T>
+void addProtocolCallback(T *obj,
+			 void (T::*func) (Widget, XtPointer, XtPointer),
+			 const WObjectClass *wo,
+			 Atom property,
+			 Atom proto_atom,
+			 XtPointer closure=NULL)
+{
+    ProtocolInfo<T> *pi = new ProtocolInfo<T>;
+
+    if (pi == NULL) return;
+
+    pi->_target     = obj;
+    pi->_widget     = wo->widget();
+    pi->_callback   = func;
+    pi->_property   = property;
+    pi->_protocol   = proto_atom;
+    pi->_closure    = closure;
+
+    registerProtoCallback(pi);
+
+}
+
+/* ====================  addWMProtocolCallback  ========================== */
+
 template <class T>
 void addWMProtocolCallback(T *obj,
 			 void (T::*func) (Widget, XtPointer, XtPointer),
@@ -89,62 +145,28 @@ void addWMProtocolCallback(T *obj,
     registerProtoCallback(pi);
 }
 
-template<class T>
-void removeCallback(T *obj, 
-                       void (T::*func) (Widget, XtPointer, XtPointer),
-                       Widget w, 
-                       _XtString type, 
-                       XtPointer closure=NULL)
-   {
-      CallbackInfo<T> ci;
+template <class T>
+void addWMProtocolCallback(T *obj,
+			 void (T::*func) (Widget, XtPointer, XtPointer),
+			 const WObjectClass *wo,
+			 Atom protocol,
+			 XtPointer closure=NULL)
+{
+    ProtocolInfo<T> *pi = new ProtocolInfo<T>;
 
-      ci._target=obj;
-      ci._widget=w;
-      ci._type=type;
-      ci._callback=func;
-      ci._closure=closure;
+    if (pi == NULL) return;
 
-      unregisterCallback(&ci);
-   }
+    pi->_target     = obj;
+    pi->_widget     = wo->widget();
+    pi->_callback   = func;
+    pi->_property   = XM_WM_PROTOCOL_ATOM(wo->widget());
+    pi->_protocol   = protocol;
+    pi->_closure    = closure;
 
-template<class T>
-void removeProtocolCallback(T *obj, 
-                            void (T::*func) (Widget, XtPointer, XtPointer),
-                            Widget w, 
-			    Atom property,
-			    Atom proto_atom,
-			    XtPointer closure=NULL)
-   {
-      ProtocolInfo<T> pi;
+    registerProtoCallback(pi);
+}
 
-      pi._target     = obj;
-      pi._widget     = w;
-      pi._property   = property;
-      pi._protocol   = proto_atom;
-      pi._callback   = func;
-      pi._closure    = closure;
-
-      unregisterProtoCallback(&pi);
-   }
-
-template<class T>
-void removeWMProtocolCallback(T *obj, 
-			      void (T::*func) (Widget, XtPointer, XtPointer),
-			      Widget w, 
-			      Atom protocol,
-			      XtPointer closure=NULL)
-   {
-      ProtocolInfo<T> pi;
-
-      pi._target     = obj;
-      pi._widget     = w;
-      pi._property   = XM_WM_PROTOCOL_ATOM(w);
-      pi._protocol   = protocol;
-      pi._callback   = func;
-      pi._closure    = closure;
-
-      unregisterProtoCallback(&pi);
-   }
+/* =========================  addWorkProc  =============================== */
 
 template <class T>
 XtWorkProcId addWorkProc(T *obj,
@@ -163,42 +185,7 @@ XtWorkProcId addWorkProc(T *obj,
     return registerWorkProc(pwi, ac);
 }
 
-template <class T>
-XtIntervalId addTimeOut(T *obj,
-			void (T::*func)(XtPointer, XtIntervalId *),
-			XtAppContext ac,
-			unsigned long interval,
-			XtPointer closure = NULL)
-{
-    TimerInfo<T> *pti = new TimerInfo<T>;
-
-    if (pti == NULL) return((XtIntervalId)0);
-
-    pti->_target     = obj;
-    pti->_callback   = func;
-    pti->_closure    = closure;
-
-    return registerTimeOut(pti, ac, interval);
-}
-
-template <class T>
-XtInputId addInput(T *obj,
-		   void (T::*func)(XtPointer, int *, XtInputId *),
-		   XtAppContext ac,
-		   int source,
-		   XtPointer condition,
-		   XtPointer closure = NULL)
-{
-    InputInfo<T> *pii = new InputInfo<T>;
-
-    if (pii == NULL) return((XtInputId)0);
-
-    pii->_target     = obj;
-    pii->_callback   = func;
-    pii->_closure    = closure;
-
-    return registerInput(pii, ac, source, condition);
-}
+/* =======================  addEventHandler  ============================= */
 
 template <class T>
 void addEventHandler(T *obj,
@@ -220,6 +207,132 @@ void addEventHandler(T *obj,
     registerEventHandler(pei);
 }
 
+template <class T>
+void addEventHandler(T *obj,
+		     void (T::*func)(Widget, XtPointer, XEvent *, Boolean *),
+		     const WObjectClass *wo,
+		     EventMask em,
+		     Boolean n_maskable,
+		     XtPointer closure = NULL)
+{
+    EventInfo<T> *pei = new EventInfo<T>;
+
+    pei->_target      = obj;
+    pei->_callback    = func;
+    pei->_closure     = closure;
+    pei->_widget      = wo->widget();
+    pei->_em          = em;
+    pei->_nonmaskable = n_maskable;
+
+    registerEventHandler(pei);
+}
+
+/* =========================  addTimeOut  ================================ */
+
+template <class T>
+XtIntervalId addTimeOut(T *obj,
+			void (T::*func)(XtPointer, XtIntervalId *),
+			XtAppContext ac,
+			unsigned long interval,
+			XtPointer closure = NULL)
+{
+    TimerInfo<T> *pti = new TimerInfo<T>;
+
+    if (pti == NULL) return((XtIntervalId)0);
+
+    pti->_target     = obj;
+    pti->_callback   = func;
+    pti->_closure    = closure;
+
+    return registerTimeOut(pti, ac, interval);
+}
+
+/* ===========================  addInput  ================================ */
+
+template <class T>
+XtInputId addInput(T *obj,
+		   void (T::*func)(XtPointer, int *, XtInputId *),
+		   XtAppContext ac,
+		   int source,
+		   XtPointer condition,
+		   XtPointer closure = NULL)
+{
+    InputInfo<T> *pii = new InputInfo<T>;
+
+    if (pii == NULL) return((XtInputId)0);
+
+    pii->_target     = obj;
+    pii->_callback   = func;
+    pii->_closure    = closure;
+
+    return registerInput(pii, ac, source, condition);
+}
+
+/* =======================  removeCallback  ============================== */
+
+template<class T>
+void removeCallback(T *obj, 
+                       void (T::*func) (Widget, XtPointer, XtPointer),
+                       Widget w, 
+                       _XtString type, 
+                       XtPointer closure=NULL)
+{
+    CallbackInfo<T> ci;
+
+    ci._target=obj;
+    ci._widget=w;
+    ci._type=type;
+    ci._callback=func;
+    ci._closure=closure;
+
+    unregisterCallback(&ci);
+}
+
+/* ===================  removeProtocolCallback  ========================== */
+
+template<class T>
+void removeProtocolCallback(T *obj, 
+                            void (T::*func) (Widget, XtPointer, XtPointer),
+                            Widget w, 
+			    Atom property,
+			    Atom proto_atom,
+			    XtPointer closure=NULL)
+{
+    ProtocolInfo<T> pi;
+
+    pi._target     = obj;
+    pi._widget     = w;
+    pi._property   = property;
+    pi._protocol   = proto_atom;
+    pi._callback   = func;
+    pi._closure    = closure;
+
+    unregisterProtoCallback(&pi);
+}
+
+/* ===================  removeWMProtocolCallback  ======================== */
+
+template<class T>
+void removeWMProtocolCallback(T *obj, 
+			      void (T::*func) (Widget, XtPointer, XtPointer),
+			      Widget w, 
+			      Atom protocol,
+			      XtPointer closure=NULL)
+{
+    ProtocolInfo<T> pi;
+
+    pi._target     = obj;
+    pi._widget     = w;
+    pi._property   = XM_WM_PROTOCOL_ATOM(w);
+    pi._protocol   = protocol;
+    pi._callback   = func;
+    pi._closure    = closure;
+
+    unregisterProtoCallback(&pi);
+}
+
+/* =====================  removeEventHandler  ============================ */
+
 template <class T>
 void removeEventHandler(T *obj,
 		     void (T::*func)(Widget, XtPointer, XEvent *, Boolean *),
