@@ -1,7 +1,8 @@
-/* $Id: CascadeB.h,v 1.3 1999/01/15 01:07:23 glgay Exp $ */
+/* $Id: CascadeB.h,v 1.5 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_CASCADEB_H_)
-#define _XARM_CASCADEB_H_
+#if !defined(xarm_cascadeb_h)
+#define xarm_cascadeb_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -34,16 +35,17 @@ class CascadeButtonClass : public LabelClass {
    virtual _XtString className() { return (_XtString) "XmCascadeButton"; }
  public:
    /* Callbacks */
-   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
-   void cascadingCallback(XtCallbackProc funcp, XtPointer data = NULL);
+   void activateCallback(XtCallbackProc fp, XtPointer data = NULL)  { XARM_SET_CALLBACK(XmNactivateCallback); }
+   void cascadingCallback(XtCallbackProc fp, XtPointer data = NULL) { XARM_SET_CALLBACK(XmNcascadingCallback); }
 
    /* resources */
-   void cascadePixmap(Pixmap);
-   Pixmap cascadePixmap() const;
-   void mappingDelay(int);
-   int mappingDelay() const;
-   void subMenuId(Widget sub); /* expects a PulldownMenu */
-   Widget subMenuId() const;
+   void cascadePixmap(Pixmap val) { XARM_SET_VALUE(XmNcascadePixmap); }
+   Pixmap cascadePixmap() const   { XARM_GET_VALUE(Pixmap, XmNcascadePixmap); }
+   void mappingDelay(int val)     { XARM_SET_VALUE(XmNmappingDelay); }
+   int mappingDelay() const       { XARM_GET_VALUE(int, XmNmappingDelay); }
+   /* expects a PulldownMenu */
+   void subMenuId(Widget val)     { XARM_SET_VALUE(XmNsubMenuId); }
+   Widget subMenuId() const       { XARM_GET_VALUE(Widget, XmNsubMenuId); }
 };
 
 class CascadeButton : public CascadeButtonClass {
