@@ -1,7 +1,7 @@
-/* $Id: ComboBox.h,v 1.9 1998/11/25 16:07:35 glgay Exp $ */
+/* $Id: ComboBox.h,v 1.11 1999/11/06 05:50:57 glgay Exp $ */
 /*
- Copyright (C) 1997 Gerald L. Gay
- Copyright (C) 1996 Peter Williams
+ Copyright (C) 1996       Peter Williams
+ Copyright (C) 1997, 1999 Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +19,8 @@
 */
 
 
-#if !defined(_XARM_COMBOBOX_H_)
-#define _XARM_COMBOBOX_H_
+#if !defined(xarm_combobox_h)
+#define xarm_combobox_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -34,7 +34,7 @@
 * However, you could write one yourself and remove this restriction.  
 */
 
-#if XmVERSION >= 2
+#if XmVERSION >= 2 && ! defined(XARM_HAS_CDE)
 
 #include <Xarm/M2ComboBox.h>
 #define XARM_HAS_COMBOBOX
