@@ -1,7 +1,8 @@
-/* $Id: Composite.h,v 1.2 1999/01/15 01:40:38 glgay Exp $ */
+/* $Id: Composite.h,v 1.4 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_COMPOSITE_H_)
-#define _XARM_COMPOSITE_H_
+#if !defined(xarm_composite_h)
+#define xarm_composite_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -30,12 +31,12 @@ class CompositeClass : public CoreClass {
  protected:
    CompositeClass() {}
 
-   virtual WidgetClass classPointer() { return compositeWidgetClass; }
-   virtual _XtString className() { return (_XtString) "Composite"; }
+   virtual WidgetClass classPointer()   { return compositeWidgetClass; }
+   virtual _XtString className()        { return (_XtString) "Composite"; }
  public:
-   void insertPosition(XtOrderProc);
-   WidgetList children() const;
-   int numChildren() const;
+   void insertPosition(XtOrderProc val) { XARM_SET_VALUE(XmNinsertPosition); }
+   WidgetList children() const          { XARM_GET_VALUE(WidgetList, XmNchildren); }
+   int numChildren() const              { XARM_GET_VALUE(int, XmNnumChildren); }
 };
 
 #endif
