@@ -1,7 +1,8 @@
-/* $Id: Constraint.h,v 1.1.1.1 1997/03/19 13:32:20 glgay Exp $ */
+/* $Id: Constraint.h,v 1.3 1999/11/06 05:50:57 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_CONSTRAINT_H_)
-#define _XARM_CONSTRAINT_H_
+#if !defined(xarm_constraint_h)
+#define xarm_constraint_h
 
 /* ======================================================================= */
 /* Include(s): */
