@@ -1,7 +1,8 @@
-/* $Id: DialogS.h,v 1.2 1997/04/07 15:33:18 glgay Exp $ */
+/* $Id: DialogS.h,v 1.4 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_DIALOGS_H_)
-#define _XARM_DIALOGS_H_
+#if !defined(xarm_dialogs_h)
+#define xarm_dialogs_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -33,14 +34,6 @@ class DialogShellClass : public TransientShellClass {
    virtual _XtString className() { return (_XtString) "XmDialogShell"; } 
 };
 
-class DialogShell : public DialogShellClass {
- public:
-   DialogShell(Widget w_parent, 
-               ArgList arglist = NULL, 
-               Cardinal cnt = 0,
-               _XtString name = NULL);
-   DialogShell(_XtString name, Widget w_parent);
-   DialogShell(Widget w_parent, XarmArg &args, _XtString name);
-};
+typedef XarmRawWidget<DialogShellClass, false> DialogShell;
 
 #endif
