@@ -1,7 +1,8 @@
-/* $Id: Display.h,v 1.2 1999/01/15 09:38:42 glgay Exp $ */
+/* $Id: Display.h,v 1.4 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_DISPLAY_H_)
-#define _XARM_DISPLAY_H_
+#if !defined(xarm_display_h)
+#define xarm_display_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -36,20 +37,20 @@ class DisplayClass : public ApplicationShellClass {
    DisplayClass() {} /* only a derived class can make this */
 
    virtual WidgetClass classPointer() { return xmDisplayClass; }
-   virtual _XtString className() { return (_XtString) "XmDisplay"; }
+   virtual _XtString className()      { return (_XtString) "XmDisplay"; }
  public:
    /* resources */
 
 #if defined(HAVE_DVB)
    /* well this seems to be missing in Motif 1.2.3 */
-   void defaultVirtualBindings(const _XtString);
-   _XtString defaultVirtualBindings();
+   void defaultVirtualBindings(const _XtString val)   { XARM_SET_VALUE(XmNdefaultVirtualBindings); }
+   _XtString defaultVirtualBindings() const           { XARM_GET_VALUE(_XtString, XmNdefaultVirtualBindings); }
 #endif
 
-   void dragInitiatorProtocolStyle(unsigned char);
-   unsigned char dragInitiatorProtocolStyle() const;
-   void dragReceiverProtocolStyle(unsigned char);
-   unsigned char dragReceiverProtocolStyle() const;
+   void dragInitiatorProtocolStyle(unsigned char val) { XARM_SET_VALUE(XmNdragInitiatorProtocolStyle); }
+   unsigned char dragInitiatorProtocolStyle() const   { XARM_GET_VALUE(unsigned char, XmNdragInitiatorProtocolStyle); }
+   void dragReceiverProtocolStyle(unsigned char val)  { XARM_SET_VALUE(XmNdragReceiverProtocolStyle); }
+   unsigned char dragReceiverProtocolStyle() const    { XARM_GET_VALUE(unsigned char, XmNdragReceiverProtocolStyle); }
 };
 
 
