@@ -1,7 +1,8 @@
-/* $Id: DrawingA.h,v 1.3 1999/01/15 09:47:23 glgay Exp $ */
+/* $Id: DrawingA.h,v 1.5 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_DRAWINGA_H_)
-#define _XARM_DRAWINGA_H_
+#if !defined(xarm_drawinga_h)
+#define xarm_drawinga_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -30,31 +31,22 @@ class DrawingAreaClass : public ManagerClass {
  protected:
    DrawingAreaClass() {}
    virtual WidgetClass classPointer() { return xmDrawingAreaWidgetClass; }
-   virtual _XtString className() { return (_XtString) "XmDrawingArea"; }
+   virtual _XtString className()      { return (_XtString) "XmDrawingArea"; }
  public:
    /* callbacks */
-   void exposeCallback(XtCallbackProc funcp, XtPointer data = NULL);
-   void inputCallback(XtCallbackProc funcp, XtPointer data = NULL); 
-   void resizeCallback(XtCallbackProc funcp, XtPointer data = NULL); 
+   void exposeCallback(XtCallbackProc fp, XtPointer data = NULL) { XARM_SET_CALLBACK(XmNexposeCallback); }
+   void inputCallback(XtCallbackProc fp, XtPointer data = NULL)  { XARM_SET_CALLBACK(XmNinputCallback); }
+   void resizeCallback(XtCallbackProc fp, XtPointer data = NULL) { XARM_SET_CALLBACK(XmNresizeCallback); }
  
    /* resources */
-   void marginHeight(Dimension); 
-   Dimension marginHeight() const; 
-   void marginWidth(Dimension);
-   Dimension marginWidth() const;
-   void resizePolicy(unsigned char);
-   unsigned char resizePolicy() const;
+   void marginHeight(Dimension val)       { XARM_SET_VALUE(XmNmarginHeight); }
+   Dimension marginHeight() const         { XARM_GET_VALUE(Dimension, XmNmarginHeight); }
+   void marginWidth(Dimension val)        { XARM_SET_VALUE(XmNmarginWidth); }
+   Dimension marginWidth() const          { XARM_GET_VALUE(Dimension, XmNmarginWidth); }
+   void resizePolicy(unsigned char val)   { XARM_SET_VALUE(XmNresizePolicy); }
+   unsigned char resizePolicy() const     { XARM_GET_VALUE(unsigned char, XmNresizePolicy); }
 };   
 
-class DrawingArea : public DrawingAreaClass {
- public:
-   DrawingArea(Widget w_parent, 
-               ArgList arglist = NULL, 
-               Cardinal cnt = 0,
-               _XtString name = NULL);
-   DrawingArea(_XtString name, Widget w_parent);
-   DrawingArea(Widget w_parent, XarmArg &args, _XtString name);
-};
-
+typedef XarmRawWidget<DrawingAreaClass, true> DrawingArea;
 
 #endif
