@@ -1,7 +1,8 @@
-/* $Id: Frame.h,v 1.3 1999/01/15 10:07:02 glgay Exp $ */
+/* $Id: Frame.h,v 1.5 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_FRAME_H_)
-#define _XARM_FRAME_H_
+#if !defined(xarm_frame_h)
+#define xarm_frame_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -29,26 +30,18 @@
 class FrameClass : public ManagerClass {
  protected:
    FrameClass() {} /* only a derived class can make this */
-   virtual WidgetClass classPointer() { return xmFrameWidgetClass; }
-   virtual _XtString className() { return (_XtString) "XmFrame"; } 
+   virtual WidgetClass classPointer()  { return xmFrameWidgetClass; }
+   virtual _XtString className()       { return (_XtString) "XmFrame"; } 
  public:
    /* resources */
-   void marginHeight(Dimension);
-   Dimension marginHeight() const;
-   void marginWidth(Dimension);
-   Dimension marginWidth() const;
-   void shadowType(unsigned char);
-   unsigned char shadowType() const;
+   void marginHeight(Dimension val)    { XARM_SET_VALUE(XmNmarginHeight); }
+   Dimension marginHeight() const      { XARM_GET_VALUE(Dimension, XmNmarginHeight); }
+   void marginWidth(Dimension val)     { XARM_SET_VALUE(XmNmarginWidth); }
+   Dimension marginWidth() const       { XARM_GET_VALUE(Dimension, XmNmarginWidth); }
+   void shadowType(unsigned char val)  { XARM_SET_VALUE(XmNshadowType); }
+   unsigned char shadowType() const    { XARM_GET_VALUE(unsigned char, XmNshadowType); }
 };
 
-class Frame : public FrameClass {
- public:
-   Frame(Widget w_parent,
-         ArgList arglist = NULL,
-         Cardinal cnt = 0,
-         _XtString name = NULL);
-   Frame(_XtString name, Widget w_parent);
-   Frame(Widget w_parent, XarmArg &args, _XtString name);
-};
+typedef XarmRawWidget<FrameClass, false> Frame;
 
 #endif
