@@ -1,4 +1,4 @@
-/* $Id: ImageCache.h,v 1.3 1999/01/14 01:15:18 glgay Exp $ */
+/* $Id: ImageCache.h,v 1.5 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1996 Peter Williams
  
@@ -17,8 +17,8 @@
  Cambridge, MA 02139, USA.
 */
 
-#if !defined(_XARM_IMAGECACHE_H_)
-#define _XARM_IMAGECACHE_H_
+#if !defined(xarm_imagecache_h)
+#define xarm_imagecache_h
 
 extern void XarmRegisterConverters();
 extern Pixmap XarmGetPixmap(Widget w, const char *fname);
