@@ -1,4 +1,4 @@
-/* $Id: MenuB.h,v 1.5 1998/11/22 15:42:50 glgay Exp $ */
+/* $Id: MenuB.h,v 1.7 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -19,8 +19,8 @@
 */
 
 
-#if !defined(_XARM_MENUB_H_)
-#define _XARM_MENUB_H_
+#if !defined(xarm_menub_h)
+#define xarm_menub_h
 
 /* Include(s): */
 #include <Xarm/RowColumn.h>
@@ -32,7 +32,6 @@ class MenuButton : public PulldownMenu {
    CascadeButton *button;
    MenuButton(Widget w_parent, char *str, KeySym mn = 0, _XtString name = NULL);
    MenuButton(_XtString name, Widget w_parent);
-   virtual ~MenuButton() { delete button; }
 };
 
 #endif
