@@ -1,4 +1,4 @@
-/* $Id: Object.h,v 1.1.1.1 1997/03/19 13:32:20 glgay Exp $ */
+/* $Id: Object.h,v 1.3 1999/11/06 05:50:58 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -19,8 +19,8 @@
 */
 
 
-#if !defined(_XARM_OBJECT_H_)
-#define _XARM_OBJECT_H_
+#if !defined(xarm_object_h)
+#define xarm_object_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -35,7 +35,8 @@ class _ObjectClass : public DropSiteClass {
  public:
    /* This is defined in BaseClass, but I put it here to follow the doc
       for Motif 1.2.  It actually just calls the one in BaseClass. */
-   void destroyCallback(XtCallbackProc funcp, XtPointer data = NULL);  
+   void destroyCallback(XtCallbackProc fp, XtPointer data = NULL)
+                     {  WObjectClass::destroyCallback(fp, data); }  
 };
 
 #endif
