@@ -1,6 +1,6 @@
 /*
- Copyright (C) 1996 Peter Williams
- Copyright (C) 1997 Gerald L. Gay
+ Copyright (C) 1996       Peter Williams
+ Copyright (C) 1997, 1999 Gerald L. Gay
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License
@@ -17,11 +17,12 @@
  Cambridge, MA 02139, USA.
 */
 
-#if !defined(_XARM_PASSWORDF_H_)
-#define _XARM_PASSWORDF_H_
+#if !defined(xarm_passwordf_h)
+#define xarm_passwordf_h
 
 #include <string>
 #include <Xarm/TextF.h>
+#include <Xarm/Xarm.h>
 
 class PasswordField : public TextField
 {
@@ -29,9 +30,14 @@ class PasswordField : public TextField
    void onModify(Widget, XtPointer, XtPointer);
    void onInit();
 
-   string passwd;
-   char filler;
-   bool PasteEnabled;
+#if defined(XARM_HAS_NAMESPACES)
+   std::string  passwd;
+#else
+   string  passwd;
+#endif
+
+   char    filler;
+   bool    PasteEnabled;
 
  public:
    PasswordField(Widget w_parent,
