@@ -1,4 +1,4 @@
-/* $Id: RootW.h,v 1.2 1997/04/07 15:33:21 glgay Exp $ */
+/* $Id: RootW.h,v 1.4 1999/11/06 05:50:59 glgay Exp $ */
 /*
  Copyright (C) 1996 Peter Williams
  
@@ -18,8 +18,8 @@
 */
 
 
-#if !defined(_XARM_ROOTW_H_)
-#define _XARM_ROOTW_H_
+#if !defined(xarm_rootw_h)
+#define xarm_rootw_h
 
 /*
  * Warning:  These classes diverge from the Motif 1.2 standard GUI and 
@@ -34,20 +34,12 @@
 class RootWindowClass : public CoreClass {
  protected:
    RootWindowClass() {}
-   virtual WidgetClass classPointer() { return xmRootWindowWidgetClass; }
-   virtual _XtString className() { return (_XtString) "XmRootWindow"; }
+   virtual WidgetClass classPointer()  { return xmRootWindowWidgetClass; }
+   virtual _XtString className()       { return (_XtString) "XmRootWindow"; }
  public:
 };
 
-class Root : public RootWindowClass {
- public:
-   Root(Widget w_parent, 
-              ArgList arglist = NULL, 
-              Cardinal cnt = 0,
-              _XtString name = NULL);
-   Root(_XtString name, Widget w_parent); 
-   Root(Widget w_parent, XarmArg &args, _XtString name);
-};
-   
+typedef XarmRawWidget<RootWindowClass, false> Root;
+
 #endif
 
