@@ -1,6 +1,6 @@
-/* $Id: SpinBox.h,v 1.3 1998/11/25 16:07:35 glgay Exp $ */
+/* $Id: SpinBox.h,v 1.5 1999/11/06 05:50:59 glgay Exp $ */
 /*
- Copyright (C) 1997 Gerald L. Gay
+ Copyright (C) 1997, 1999 Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -18,8 +18,8 @@
 */
 
 
-#if !defined(_XARM_SPINBOX_H_)
-#define _XARM_SPINBOX_H_
+#if !defined(xarm_spinbox_h)
+#define xarm_spinbox_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -32,7 +32,7 @@
 * However, you could write one yourself and remove this restriction.  
 */
 
-#if XmVERSION >= 2
+#if XmVERSION >= 2 && ! defined(XARM_HAS_CDE)
 
 #include <Xarm/M2SpinBox.h>
 #define XARM_HAS_SPINBOX
