@@ -1,7 +1,8 @@
-/* $Id: WorkArea.h,v 1.2 1997/04/07 15:33:23 glgay Exp $ */
+/* $Id: WorkArea.h,v 1.4 1999/11/06 05:51:00 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
+ Copyright (C) 1999       Gerald L. Gay
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public License 
@@ -19,8 +20,8 @@
 */
 
 
-#if !defined(_XARM_WORKAREA_H_)
-#define _XARM_WORKAREA_H_
+#if !defined(xarm_workarea_h)
+#define xarm_workarea_h
 
 /* ======================================================================= */
 /* Include(s): */
@@ -31,10 +32,6 @@ class WorkAreaClass : public RowColumnClass {
    WorkAreaClass() {} /* only a derived class can make this */
 };
 
-class WorkArea : public WorkAreaClass {
- public:
-   WorkArea(Widget w_parent, ArgList arglist = NULL, Cardinal cnt = 0);
-   WorkArea(Widget w_parent, XarmArg &args, _XtString name);
-};
+typedef XarmRawWidget<WorkAreaClass, false> WorkArea;
 
 #endif
