@@ -1,4 +1,4 @@
-/* $Id: XarmXpm.h,v 1.2 1999/01/14 03:08:53 glgay Exp $ */
+/* $Id: XarmXpm.h,v 1.4 1999/11/06 05:51:00 glgay Exp $ */
 /*
  Copyright (C) 1996 Peter Williams
  
@@ -47,8 +47,8 @@
  * in this Software without prior written authorization from GROUPE BULL.
  */
 
-#if !defined(_XARM_XPM_H_)
-#define _XARM_XPM_H_
+#if !defined(xarm_xarmxpm_h)
+#define xarm_xarmxpm_h
 
 #include <X11/X.h>
 #include <X11/IntrinsicP.h>
@@ -266,5 +266,5 @@ extern int	_XarmXpmReadFileToPixmap(Display *display,
 }
 #endif
 
-#endif /* _XARM_XPM_H_ */
+#endif /* xarm_xarmxpm_h */
 
