@@ -847,7 +847,12 @@ static void DrawPointer (Display *display, Window window, XmDialWidget dialw,
     double fyradius = (double)(dialw->dial.yradius - 4);
     double pntxradius = fxradius / 5.0;
     double pntyradius = fyradius / 5.0;
-    XRectangle rect[] = {0, 0, dialw->core.width, dialw->dial.yorigin};
+    XRectangle rect[1];
+
+    rect[0].x      = 0;
+    rect[0].y      = 0;
+    rect[0].width  = dialw->core.width;
+    rect[0].height = dialw->dial.yorigin;
 
     XSetClipRectangles(XtDisplay((Widget)(dialw)), dialw->dial.foreground_GC,
                        0, 0, rect, 1, Unsorted);
