@@ -251,7 +251,7 @@ static void TroughPixelDefault (XmGaugeWidget widget, int offset, XrmValue *valu
 
     value->addr = (caddr_t) &trough;
 
-    pixel_data = _XmGetColors(XtScreen((Widget)widget),
+    pixel_data = (XmColorData *)_XmGetColors(XtScreen((Widget)widget),
         widget->core.colormap, widget->core.background_pixel);
 
     trough = _XmAccessColorData(pixel_data, XmSELECT);
@@ -490,11 +490,6 @@ static void Redisplay (XmGaugeWidget gaugew, XEvent *event, Region region)
                 XmSHADOW_IN);
 #endif
 
-    /*
-    ** Draw the Gauge widget.
-    */
-    DrawGauge(gaugew);
-
     /*
     ** Copy in the slider pixmap.
     */
@@ -514,6 +509,11 @@ static void Redisplay (XmGaugeWidget gaugew, XEvent *event, Region region)
                  gaugew->gauge.slider_height,
                  gaugew->gauge.slider_x, gaugew->gauge.slider_y);
 
+    /*
+    ** Draw the Gauge widget.
+    */
+    DrawGauge(gaugew);
+
     (*(((XmPrimitiveWidgetClass) XtClass(gaugew))
         ->primitive_class.border_unhighlight)) ((Widget)gaugew);
 }
@@ -582,7 +582,7 @@ static void Resize (XmGaugeWidget gaugew)
         gaugew->gauge.minimum_y = height - margin;
         gaugew->gauge.maximum_y = height - margin;
         gaugew->gauge.value_y = gaugew->gauge.show_min_max ? height - margin :
-            height / 2 + text_height / 2 + gaugew->gauge.font->descent;
+            height / 2 + text_height / 2 + gaugew->gauge.font->descent + margin;
 
     }
     else    
@@ -598,7 +598,7 @@ static void Resize (XmGaugeWidget gaugew)
             SWAP(gaugew->gauge.minimum_y, gaugew->gauge.maximum_y);
     }
 
-     if (XtIsRealized(gaugew))
+     if (XtIsRealized((Widget)gaugew))
     {
        if (gaugew->gauge.pixmap)
        {
@@ -914,7 +914,7 @@ static void RedrawSlider (XmGaugeWidget gaugew)
         &(gaugew->gauge.slider_y), &(gaugew->gauge.slider_width),
         &(gaugew->gauge.slider_height));
 
-    if (XtIsRealized(gaugew))
+    if (XtIsRealized((Widget)gaugew))
     {
         if (!gaugew->gauge.show_percentage ||
             (gaugew->gauge.show_percentage && 
@@ -1300,7 +1300,7 @@ void XmSetGaugeColorThreshold (XmGaugeWidget gaugew, int value, String color_nam
     XrmValue        from;
     XrmValue        to;
 
-    if (XtIsRealized(gaugew))
+    if (XtIsRealized((Widget)gaugew))
     {
         from.addr = p->color_name;
         from.size = strlen(p->color_name);
